@@ -179,7 +179,7 @@ static void truncate_file(void)
 
 static void firstTimeHelp(void)
 {
-  int firstTime = TRUE;
+  static int firstTime = TRUE;
 
   if (firstTime) {
     firstTime = FALSE;
@@ -342,6 +342,7 @@ int key_to_function(int key)
   switch (key)
     {
     case ERR:
+    case KEY_RESIZE:
       /*no-op*/
       break;
 
@@ -662,8 +663,8 @@ static void escaped_command(void)
     break;
 
   case '[': 
-    for (i = 0;; i++) { tmp[i] = c = getch(); if (!isdigit(c)) break; }
-    tmp[i + 1] = '\0';
+    for (i = 0; i < BLOCK_SEARCH_SIZE - 1; i++) { tmp[i] = c = getch(); if (!isdigit(c)) break; }
+    tmp[i < BLOCK_SEARCH_SIZE - 1 ? i + 1 : i] = '\0';
     
     if (0);
     else if (streq(tmp, "2~")) yank();
